@@ -18,22 +18,12 @@
 using namespace Akregator;
 
 K_PLUGIN_CLASS_WITH_JSON(KCMAkregatorAppearanceConfig, "akregator_config_appearance.json")
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-KCMAkregatorAppearanceConfig::KCMAkregatorAppearanceConfig(QWidget *parent, const QVariantList &args)
-    : KCModule(parent, args)
-    , m_widget(new QWidget(this))
-#else
-KCMAkregatorAppearanceConfig::KCMAkregatorAppearanceConfig(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
-    : KCModule(parent, data, args)
+KCMAkregatorAppearanceConfig::KCMAkregatorAppearanceConfig(QObject *parent, const KPluginMetaData &data)
+    : KCModule(parent, data)
     , m_widget(new QWidget(widget()))
-#endif
 {
     m_ui.setupUi(m_widget);
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    auto layout = new QVBoxLayout(this);
-#else
     auto layout = new QVBoxLayout(widget());
-#endif
     layout->addWidget(m_widget);
 
     connect(m_ui.kcfg_UseCustomColors, &QAbstractButton::toggled, m_ui.kcfg_ColorUnreadArticles, &QWidget::setEnabled);
@@ -59,3 +49,5 @@ KCMAkregatorAppearanceConfig::KCMAkregatorAppearanceConfig(QObject *parent, cons
 }
 
 #include "akregator_config_appearance.moc"
+
+#include "moc_akregator_config_appearance.cpp"
