@@ -5,7 +5,6 @@
 */
 
 #pragma once
-#include "kcmutils_version.h"
 #include <KCModule>
 #include <QVariant>
 namespace PimCommon
@@ -19,11 +18,7 @@ class KCMAkregatorPluginsConfig : public KCModule
 {
     Q_OBJECT
 public:
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    explicit KCMAkregatorPluginsConfig(QWidget *parent, const QVariantList &args);
-#else
-    explicit KCMAkregatorPluginsConfig(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
-#endif
+    explicit KCMAkregatorPluginsConfig(QObject *parent, const KPluginMetaData &data);
     void load() override;
     void save() override;
     void defaults() override;
