@@ -22,5 +22,5 @@ public:
 
 private:
     void slotConfigureClicked(const QString &configureGroupName, const QString &identifier);
-    QVector<PluginItem *> mPluginWebEngineItems;
+    QList<PluginItem *> mPluginWebEngineItems;
 };
