@@ -5,7 +5,6 @@
 */
 
 #include "akregatoruserfeedbackprovider.h"
-#ifdef USE_KUSERFEEDBACK_QT6
 #include <KUserFeedbackQt6/ApplicationVersionSource>
 #include <KUserFeedbackQt6/LocaleInfoSource>
 #include <KUserFeedbackQt6/PlatformInfoSource>
@@ -13,15 +12,6 @@
 #include <KUserFeedbackQt6/ScreenInfoSource>
 #include <KUserFeedbackQt6/StartCountSource>
 #include <KUserFeedbackQt6/UsageTimeSource>
-#else
-#include <KUserFeedback/ApplicationVersionSource>
-#include <KUserFeedback/LocaleInfoSource>
-#include <KUserFeedback/PlatformInfoSource>
-#include <KUserFeedback/QtVersionSource>
-#include <KUserFeedback/ScreenInfoSource>
-#include <KUserFeedback/StartCountSource>
-#include <KUserFeedback/UsageTimeSource>
-#endif
 using namespace Akregator;
 AkregatorUserFeedbackProvider::AkregatorUserFeedbackProvider(QObject *parent)
     : KUserFeedback::Provider(parent)
@@ -44,3 +34,5 @@ AkregatorUserFeedbackProvider::AkregatorUserFeedbackProvider(QObject *parent)
 }
 
 AkregatorUserFeedbackProvider::~AkregatorUserFeedbackProvider() = default;
+
+#include "moc_akregatoruserfeedbackprovider.cpp"
