@@ -8,10 +8,10 @@
 #include "articlematcher.h"
 #include "akregator_debug.h"
 #include "article.h"
-#include "utils/textutil.h"
 #include <KConfig>
 #include <KConfigGroup>
 #include <QUrl>
+#include <TextUtils/ConvertText>
 
 #include <QRegularExpression>
 
@@ -160,17 +160,17 @@ bool Criterion::satisfiedBy(const Article &article) const
 
     switch (predicateType) {
     case Contains:
-        satisfied = TextUtil::normalize(concreteSubject.toString()).indexOf(m_object.toString(), 0, Qt::CaseInsensitive) != -1;
+        satisfied = TextUtils::ConvertText::normalize(concreteSubject.toString()).indexOf(m_object.toString(), 0, Qt::CaseInsensitive) != -1;
         break;
     case Equals:
         if (subjectType == QLatin1String("int")) {
             satisfied = concreteSubject.toInt() == m_object.toInt();
         } else {
-            satisfied = TextUtil::normalize(concreteSubject.toString()) == m_object.toString();
+            satisfied = TextUtils::ConvertText::normalize(concreteSubject.toString()) == m_object.toString();
         }
         break;
     case Matches:
-        satisfied = TextUtil::normalize(concreteSubject.toString()).contains(QRegularExpression(m_object.toString()));
+        satisfied = TextUtils::ConvertText::normalize(concreteSubject.toString()).contains(QRegularExpression(m_object.toString()));
         break;
     default:
         qCDebug(AKREGATOR_LOG) << "Internal inconsistency; predicateType should never be Negation";
@@ -206,7 +206,7 @@ ArticleMatcher::ArticleMatcher()
 
 ArticleMatcher::~ArticleMatcher() = default;
 
-ArticleMatcher::ArticleMatcher(const QVector<Criterion> &criteria, Association assoc)
+ArticleMatcher::ArticleMatcher(const QList<Criterion> &criteria, Association assoc)
     : m_criteria(criteria)
     , m_association(assoc)
 {
