@@ -10,22 +10,19 @@
 #include <KIO/JobUiDelegateFactory>
 #include <KIO/OpenUrlJob>
 #include <KLocalizedString>
+#include <MessageViewer/PrintMessage>
 #include <MessageViewer/ViewerPluginToolManager>
 #include <QVBoxLayout>
-#include <kio_version.h>
 #ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
 #include <TextEditTextToSpeech/TextToSpeechContainerWidget>
 #endif
-#include <KPIMTextEdit/SlideContainer>
+#include <TextAddonsWidgets/SlideContainer>
 
 #include <WebEngineViewer/FindBarWebEngineView>
 #include <WebEngineViewer/TrackingWarningWidget>
 #include <WebEngineViewer/WebEngineExportHtmlPageJob>
 
 #include <QApplication>
-#include <QPrintDialog>
-#include <QPrintPreviewDialog>
-#include <QPrinter>
 
 using namespace Akregator;
 template<typename Arg, typename R, typename C>
@@ -51,7 +48,7 @@ ArticleViewerWebEngineWidgetNg::ArticleViewerWebEngineWidgetNg(ArticleViewerWebE
 #ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
     , mTextToSpeechWidget(new TextEditTextToSpeech::TextToSpeechContainerWidget(this))
 #endif
-    , mSliderContainer(new KPIMTextEdit::SlideContainer(this))
+    , mSliderContainer(new TextAddonsWidgets::SlideContainer(this))
     , mTrackingWarningWidget(new WebEngineViewer::TrackingWarningWidget(this))
 
 {
@@ -86,7 +83,7 @@ void ArticleViewerWebEngineWidgetNg::initializeLayout(KActionCollection *ac)
     mSliderContainer->setObjectName(QStringLiteral("slidercontainer"));
     mFindBarWebView = new WebEngineViewer::FindBarWebEngineView(mArticleViewerNg, this);
     mFindBarWebView->setObjectName(QStringLiteral("findbarwebview"));
-    connect(mFindBarWebView, &WebEngineViewer::FindBarWebEngineView::hideFindBar, mSliderContainer, &KPIMTextEdit::SlideContainer::slideOut);
+    connect(mFindBarWebView, &WebEngineViewer::FindBarWebEngineView::hideFindBar, mSliderContainer, &TextAddonsWidgets::SlideContainer::slideOut);
     mSliderContainer->setContent(mFindBarWebView);
     layout->addWidget(mSliderContainer);
     connect(articleViewerNg(), &ArticleViewerWebEngine::textToSpeech, this, &ArticleViewerWebEngineWidgetNg::slotSpeakText);
@@ -124,55 +121,19 @@ void ArticleViewerWebEngineWidgetNg::saveCurrentPosition()
 
 void ArticleViewerWebEngineWidgetNg::slotPrint()
 {
-    printRequested(mArticleViewerNg->page());
-}
-
-void ArticleViewerWebEngineWidgetNg::printRequested(QWebEnginePage *page)
-{
-    if (mCurrentPrinter) {
-        return;
-    }
-    mCurrentPrinter = new QPrinter();
-    QPointer<QPrintDialog> dialog = new QPrintDialog(mCurrentPrinter, this);
-    dialog->setWindowTitle(i18nc("@title:window", "Print Document"));
-    if (dialog->exec() != QDialog::Accepted) {
-        slotHandlePagePrinted(false);
-        delete dialog;
-        return;
-    }
-    delete dialog;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    page->print(mCurrentPrinter, invoke(this, &ArticleViewerWebEngineWidgetNg::slotHandlePagePrinted));
-#else
-#pragma "Fix port printing"
-#endif
-}
-
-void ArticleViewerWebEngineWidgetNg::slotHandlePagePrinted(bool result)
-{
-    Q_UNUSED(result)
-    delete mCurrentPrinter;
-    mCurrentPrinter = nullptr;
+    auto printMessage = new MessageViewer::PrintMessage(this);
+    printMessage->setParentWidget(this);
+    printMessage->setView(mArticleViewerNg);
+    printMessage->print();
 }
 
 void ArticleViewerWebEngineWidgetNg::slotPrintPreview()
 {
-    auto dialog = new QPrintPreviewDialog(this);
-    dialog->setAttribute(Qt::WA_DeleteOnClose);
-    dialog->resize(800, 750);
-
-    connect(dialog, &QPrintPreviewDialog::paintRequested, this, [=](QPrinter *printing) {
-        QApplication::setOverrideCursor(Qt::WaitCursor);
-
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        mArticleViewerNg->execPrintPreviewPage(printing, 10 * 1000);
-#else
-        mArticleViewerNg->printPreviewPage(printing);
-#endif
-        QApplication::restoreOverrideCursor();
-    });
-
-    dialog->open();
+    qDebug() << " print preview ";
+    auto printMessage = new MessageViewer::PrintMessage(this);
+    printMessage->setParentWidget(this);
+    printMessage->setView(mArticleViewerNg);
+    printMessage->printPreview();
 }
 
 void ArticleViewerWebEngineWidgetNg::slotOpenInBrowser()
@@ -204,3 +165,5 @@ void ArticleViewerWebEngineWidgetNg::slotExportHtmlPageSuccess(const QString &fi
     job->setDeleteTemporaryFile(true);
     job->start();
 }
+
+#include "moc_articleviewerwebenginewidgetng.cpp"
