@@ -121,7 +121,7 @@ void MainWindow::slotToggleMenubar(bool dontShowWarning)
                                          i18n("<qt>This will hide the menu bar completely."
                                               " You can show it again by typing %1.</qt>",
                                               accel),
-                                         i18n("Hide menu bar"),
+                                         i18nc("@title:window", "Hide menu bar"),
                                          QStringLiteral("HideMenuBarWarning"));
             }
             menuBar()->hide();
@@ -133,7 +133,7 @@ void MainWindow::slotToggleMenubar(bool dontShowWarning)
 void MainWindow::updateHamburgerMenu()
 {
     auto menu = new QMenu(this);
-    menu->addAction(actionCollection()->action(QLatin1String(KStandardAction::name(KStandardAction::Quit))));
+    menu->addAction(actionCollection()->action(KStandardAction::name(KStandardAction::Quit)));
     mHamburgerMenu->setMenu(menu);
 }
 
@@ -284,3 +284,5 @@ void MainWindow::slotSetStatusBarText(const QString &text)
 {
     m_statusLabel->setText(text);
 }
+
+#include "moc_mainwindow.cpp"
