@@ -7,7 +7,6 @@
 */
 
 #include "trayicon.h"
-#include "akregatorconfig.h"
 
 #include <KLocalizedString>
 
@@ -61,3 +60,5 @@ void TrayIcon::settingsChanged()
 {
     slotSetUnread(m_unread);
 }
+
+#include "moc_trayicon.cpp"
