@@ -10,7 +10,7 @@
 #include "akregatorconfig.h"
 
 #include "article.h"
-#include "utils/textutil.h"
+#include <TextUtils/ConvertText>
 
 #include <KLineEdit>
 #include <KLocalizedString>
@@ -129,11 +129,11 @@ void SearchBar::slotStopActiveSearch()
 
 void SearchBar::slotActivateSearch()
 {
-    QVector<Criterion> textCriteria;
-    QVector<Criterion> statusCriteria;
+    QList<Criterion> textCriteria;
+    QList<Criterion> statusCriteria;
 
     if (!m_searchText.isEmpty()) {
-        const QString searchTextDiacritic(TextUtil::normalize(m_searchText));
+        const QString searchTextDiacritic(TextUtils::ConvertText::normalize(m_searchText));
         textCriteria.reserve(3);
         Criterion subjCrit(Criterion::Title, Criterion::Contains, searchTextDiacritic);
         textCriteria << subjCrit;
@@ -191,3 +191,5 @@ void Akregator::SearchBar::triggerTimer()
 
     m_timer.start(200ms);
 }
+
+#include "moc_searchbar.cpp"
